==> cmail_2.60+19991208.orig.tar.gz: cmail-2.60+19991208.orig/cmail-res.el <==
;;;
;;;  cmail-res.el
;;;

(setq cmail-resource-alist
      '(
	;; cmail.el
	(start-1 . "Folder")
	(get-spooled-mail-1 . "Recovering messages from crash box...")
	(get-spooled-mail-2 . "Recovering messages from crash box... done")
	(get-spooled-mail-3 . "POP Password?: ")
	(get-spooled-mail-4 . "POP Password for %s?: ")
	(get-spooled-mail-5 . "Getting mail from post office %s...")
	(get-spooled-mail-6 . "Getting mail from post office %s... done")
	(get-spooled-mail-7 . "Getting new mail from %s...")
	(get-spooled-mail-8 . "Getting new mail from %s... done")
	(get-spooled-mail-9 . "no new mail.") ;cmail-folders-get-newmail
	(get-spooled-mail-10 . "Crash box is too large (%d bytes), and yet want to get?")
	(get-spooled-mail-11 . "Stop getting new mail.")
	(get-spooled-mail-12 . "The environment variable \"MAILHOST\" is not set.")

	(copy-to-folder-1 . "Copy to folder")
	(move-to-folder-1 . "Move to folder")
	(move-to-folder-2 . "Same FOLDER.")
	(move-to-folder-3-1 . "Copying mails...")
	(move-to-folder-3-2 . "Moving mails...")
					;                     7/8
	(move-to-folder-4-1 . "Copying mails... done (%0;d mail%1;s copied into %2;s)")
	(move-to-folder-4-2 . "Moving mails... done (%0;d mail%1;s moved into %2;s)")
	(move-to-folder-7 . "s")
	(move-to-folder-8 . "")
	(refile-call-1 . "mail %d not found.")
	(read-contents-1 . "no mail.")
	(read-contents-2 . "no more mail.")
	(show-contents-1 . "end of folder.")
	(read-reverse-1 . "Beginning of message.")
	(next-unread-mail-1 . "No more unread mails")
	(prepare-caesar-1 . "Building caesar-translate-table...")
	(prepare-caesar-2 . "Building caesar-translate-table... done")
	(delete-bk-file-1 . "File %s does not exist.")
	(delete-bk-file-2 . "Delete file %s. Are you sure?")
	(delete-bk-file-3 . "File %s deleted.")
	(visit-folder-1 . "Visit folder") ; cmail-folders-visit-folder-directly-withou-thread, cmail-folders-visit-folder-directly
	(visit-folder-2 . "How many mails from %0;s(%1;d mails): ")
	(kill-folder-1 . "Remove folder")
	(kill-folder-2 . "Can't remove %s")
	(kill-folder-3 . "Remove %s, are you sure?")
	(kill-folder-4 . "terminated.")
	(kill-folder-5 . "Folder %s removed.")
	(copy-folder-1 . "Copy folder %s to")
	(copy-folder-2 . "folder %s is virtual.") ; used in cmail-rename-folder, too.
	(copy-folder-3 . "folder %s exists.") ; used in cmail-rename-folder, too.
	(copy-folder-4 . "folder %0;s copyed to %1;s.")
	(rename-folder-1 . "Rename folder %s to")
	(rename-folder-4 . "folder %0;s renamed to %1;s.")
	(reorder-folder-1 . "Are you sure to reorder %s?")
	(reorder-folder-2 . "Terminated.")
	(reorder-folder-3 . "Reordering %0;s...%1;d")
	(reorder-folder-4 . "Re-ordering %s... done")
	(saving-folder-1 . "Saving folder is %s")
	(saving-folder-2 . "No saving folder")
	(mark-specified-mails-1 . "Header:")
	(mark-specified-mails-2 . "Pattern for Header %s: ")
	(auto-archive-1 . "Do you want to refile %s?")
	(auto-archive-2 . "auto-refile terminated.")
	(auto-archive-3 . "Archiving...")
	(auto-archive-4 . "Archiving...%d")
	(auto-archive-5 . "Archiving... done.")
	(visit-saving-foler-1 . "Visit folder %s. Sure?")
	(scroll-up-1 . "end of message.")
	(scroll-down-1 . "beginnig of message.")
	(print-1 . "Are you ready to print this mail?")
	(print-2 . "Terminated.")
	(print-3 . "Printing...")
	(print-4 . "Printing...done.")
	(pipe-1 . "Pipe to command: ")
	(pipe-2 . "piping out message(s)...")
	(pipe-3 . "piping out message(s)... done")
	(name-and-address-1 . "get failed <get failed>")
	(name-and-address-2 . "E-mailed from... %s")
	(name-and-address-3 . "Failed.")
	(save-folder-1 . "no folder %s to save")
	(save-folder-2 . "Saving folder %s. Are you sure.?")
	(save-folder-3 . "%s is saved.")
	(save-folder-4 . "%s is not modified.")
	(save-folder-5 . "")
	(save-all-folders-1 . "folders are saved.")
	(save-all-folders-2 . "all folders are not modified.")
	(close-folder-1 . "Can't close folder %s")

	;; cmail-reply.el
	(mail2-1 . "Unsent message exists: a)bandon, r)ename or i)nclude new citation? ")
	(mail2-2 . "Unsent message exists: a)bandon or r)ename? ")
	(mail2-3 . "Previous *mail* buffer renamed to %s")
	(mail2-4 . "Merged new citation in *mail*")
	(mail2-5 . "Previous *mail* deleted")
	(mail2-6 . "Subject: ")
	(reply-1 . "%0;s's message of \"%1;s\"%2;s")
	(reply-2 . "reply for your message") ; default reply subject for empty subject
	(setup-reply-buffer-1 . "failed to get value in index.")
	(make-reply-headings-1 . "your message")
	(forward-1 . "Forward: %s")	; Subject prefix for forwarding mails
	(forward-2 . "forward")		; Default subject for forwarding mails
	(mail-this-line-1 . "Subject: ")
	(send-1 . "Are you need log ")
	(complete-address-1 . "can't find completion for \"%s\"")
	(complete-address-2 . "Making completion list...")
	(complete-address-3 . "Making completion list... done")
	(add-new-address-from-mail-1 . "Registering address: ")
	(add-new-address-from-mail-2 . "Register <%s> to .addresses?")
	(resend-bounced-mail-1 . "This does not appear to be a bounced message.")
	(resend-bounced-mail-2 . "retry of %0;s:%1;d") ; Subject?
	(mail-compose-1 . "R)eply or F)ollow ?")

	;; cmail-folders.el
	(folders-count-mails-1 . "Scannig %s...")
	(folders-count-mails-2 . "Scannig %s... done")
	(folders-load-cache-1 . "Updating folder list...")
	(folders-load-cache-2 . "Updating folder list... done")
	(after-save-all-folders-function-1 . "Saving cmail-folders cache file...") ;used in cmail-after-quit-function, too.
	(after-quit-function-2 . "Saving cmail-folders cache file... done")
	(folders-previous-unread-folder-1 . "No more unread folders") ; used in cmail-folders-next-unread-folder, too
	(folders-update-1 . "Saving folders...")
	(folders-update-2 . "Updating folder list...")
	(folders-update-3 . "Updating folder list... done")
	(folders-copy-folder-1 . "Copy folder %s to")
	(folders-copy-folder-2 . "Don't point folder.")
	(folders-rename-folder-1 . "Rename folder %s to")
	(folders-rename-folder-2 . "Don't point folder.")
	(folders-kill-dir-1 . "Remove %s, are you sure?")
	(folders-kill-folder-1 . "Don't point folder.")
	(folders-kill-folder-2 . "Can't kill a parent directory.")
	(folders-quit-internal-1 . "Are you sure you want to quit cmail?")
	(folders-close-all-folders-1 . "%s closed.")
	(folders-close-all-folders-2 . "Done.")

	;; cmail-summary.el
	(make-summary-1 . "Listing %s ...")
	(make-summary-2 . "Listing %s ... Error.")
	(make-summary-3 . "    0  \n")
	(make-summary-4 . "    0  ******** Error in listing Summary.\n")
	(make-summary-5 . "    0  ******** Possible Folder Headings data corruption.\n")
	(make-summary-6 . "    0  ******** Consider running M-x cmail-remake-folder-headings (normally M-r).\n")
	(make-summary-7 . "    0  \n")
	(make-summary-8 . "Listing %s ... Quit.")
	(make-summary-9 . "    0  \n")
	(make-summary-10 . "    0  ******** Summary Listing Interrupted.\n")
	(make-summary-11 . "    0  ******** M-x cmail-make-summary to restart.\n")
	(make-summary-12 . "    0  \n")
	(make-summary-13 . "Listing %s ...done.")
	(make-summary-line-1 . " %4s  ********  bad header format  ********\n")
	(summary-limit-1 . "can't set limit in thread-mode")
	(summary-limit-2 . "Summarize limit: ")
	(summary-limit-3 . "unset summarize limit.")
	(remake-folder-headings-1 . "Remake index, now you lose MARK data. Are you sure?")
	(remake-folder-headings-2 . "terminated.")
	(remake-folder-headings-3 . "Remake...")
	(remake-folder-headings-4 . "Remake...%d")
	(remake-folder-headings-5 . "done")
	(remake-folder-headings-6 . "Remake...done")
	(execute-index-1 . "Delete mail as index, now you lose some mails. Sure?")
	(execute-index-2 . "terminated.")
	(execute-index-3 . "Executing %s...")
	(execute-index-4 . "Executing %s... done")
	(diet-folder-1 . "Diet...")
	(diet-folder-2 . "Diet...%d")
	(diet-folder-3 . "Diet...done. %0;s contains %1;d mail%2;s.")
	(diet-folder-4 . "")
	(diet-folder-5 . "s")
	(sort-index-1 . "Sorting field:")
	(move-index-1 . "can't move index in thread-mode")
	(move-index-2 . "Moving index...")
	(move-index-3 . "no marks in this folder.")
	(move-index-4 . "Moving index...%0;d index%1;s moved.")
	(move-index-5 . "")
	(move-index-6 . "es")
	; *** cmail-goto-index (interactive "Ngoto mail:")
	(expire-mark-1 . "Expiring %s...")
	(expire-mark-2 . "Expiring %s... done")
	(catch-up-all-1 . "Do you really want to mark everything as read? ")
	(catch-up-all-2 . "Mark all unread mails as read?")
	(catch-up-all-3 . "marking...")
	(catch-up-all-4 . "marking... done")
	(mark-confirm-1 . "Type \\[delete-other-windows] to remove confirm window.")
	(mark-confirm-2 . "Type \\[switch-to-buffer] RET to remove confirm window.")
	(mark-confirm-3 . "Type \\[switch-to-buffer-other-window] RET to restore old contents of confirm window.")
	(mark-confirm-4 . "No mail marked by `%c'.")

	;; cmail-digest.el
	(burst-digest-1 . "bursting diests...")
	(burst-digest-2 . "bursting diests... done")
	(burst-internal-1 . "mail does not seem like a digest.")
	(send-digest-1 . "digest of folder %s")	;Subject:
	(send-digest-2 . "making digest...")
	(send-digest-3 . "making digest... done")

	;; cmail-misc.el
	(get-page-number-from-summary . "no mail.")
	(rebuild-index-1 . "in summary")
	(rebuild-index-2 . "Counting mails in %s...")
	(clean-virtual-folders-1 . "Mails in virtual folders may be lost. Sure?")
	(clean-virtual-folders-2 . "Terminated")
	(complete-foldername-1 . "%s(default %s): ")
	(complete-foldername-2 . "file %s is a directory.")
	(complete-filename-1 . "%s (default %s) ")
	(complete-filename-2 . "Bad match.")
	(open-folder-1 . "create new foler `%s'")
	(open-folder-2 . "folder `%s' was not created.")
	(delete-mail-1 . "Deleting this mail. Are you sure?")

	;; cmail-search.el
	(summary-search-article-forward-1 . "Search forward (regexp): ")
	(summary-search-article-forward-2 . "(default %s) ")
	(summary-search-article-forward-3 . "Search failed: %s")
	(summary-search-article-backward-1 . "Search backward (regexp): ")

	;; cmail-thread.el
	(refer-article-1 . "No references around point")
	(refer-article-mid-1 . "No parent")
	(refer-article-mid-2 . "Not found in folder %0;s - %1;s")
	(refer-article-mid-3 . "Mail %d not shown in summary")

	;; cmail-trans.el
	(m2c-1 . "Converting mbox file:")
	(m2c-2 . "Move all to folder")
	(m2c-3 . "Converting...")
	(m2c-4 . "Converting...done %0;d mbox-formed mail%1;s read")
	(m2c-5 . "")
	(m2c-6 . "s")
	(r2c-1 . "Converting RMAIL file:")
	(r2c-2 . "Move all to folder")
	(r2c-3 . "Converting...")
	(r2c-4 . "CM:File %s is not in format of RMAIL.")
	(r2c-5 . "Converting...done")
	(r2c-6 . "%0;d RMAIL-formed mail%1;s read")
	(r2c-7 . "")
	(r2c-8 . "s")
	(c2m-1 . "Convert folder")
	(c2m-2 . "%0;s %1;s in Unix mail file:")
	(c2m-3 . "Converting...")
	(c2m-4 . "Converting...done.")
	(save-mail-as-mbox-1 . "Save mail(s) in Unix mail file:")
	(save-mail-as-mbox-2 . "Done.")
	(save-mail-1 . "Save mail(s) in file:")
	(save-mail-2 . "Done.")

	;; cmail-edit.el
	(edit-1 . "Edit this message. Are you sure?")
	(edit-2 . "Terminated.")
	(edit-3 . "\\[cmail-cease-edit] to return cmail summary. \\[cmail-abort-edit] to abort.")
	(cease-edit-1 . "current folder changed while editing.")
	(cease-edit-2 . "Finish editing.")
	(abort-edit-1 . "Are you sure to abort?")
	(abort-edit-2 . "Abort editing.")
	(abort-edit-3 . "Continue editing.")
	(edit-index-1 . "Edit index of this mail. Are you sure?")
	(edit-index-2 .  "abort.")
	(edit-index-3 . "Edit index: ")
	(edit-index-4 . "abort.")
	(edit-index-5 . "done.")
))

==> cmail-2.61.1.tar.gz: cmail-2.61.1/cmail-res.el <==
;;;
;;;  cmail-res.el
;;;

(setq cmail-resource-alist
      '(
	;; cmail.el
	(start-1 . "Folder")
	(get-spooled-mail-1 . "Recovering messages from crash box...")
	(get-spooled-mail-2 . "Recovering messages from crash box... done")
	(get-spooled-mail-3 . "POP Password?: ")
	(get-spooled-mail-4 . "POP Password for %s?: ")
	(get-spooled-mail-5 . "Getting mail from post office %s...")
	(get-spooled-mail-6 . "Getting mail from post office %s... done")
	(get-spooled-mail-7 . "Getting new mail from %s...")
	(get-spooled-mail-8 . "Getting new mail from %s... done")
	(get-spooled-mail-9 . "no new mail.") ;cmail-folders-get-newmail
	(get-spooled-mail-10 . "Crash box is too large (%d bytes), and yet want to get?")
	(get-spooled-mail-11 . "Stop getting new mail.")
	(get-spooled-mail-12 . "The environment variable \"MAILHOST\" is not set.")
	(get-spooled-mail-13 . "Incorrect cmail-mail-spools format.")
	(save-pass-1 . "Create new password file? ")
	(save-pass-2 . "Not a secure file system - file not created.")
	(save-pass-3 . "Create new password record? ")
	(copy-to-folder-1 . "Copy to folder")
	(move-to-folder-1 . "Move to folder")
	(move-to-folder-2 . "Same FOLDER.")
	(move-to-folder-3-1 . "Copying mails...")
	(move-to-folder-3-2 . "Moving mails...")
					;                     7/8
	(move-to-folder-4-1 . "Copying mails... done (%0;d mail%1;s copied into %2;s)")
	(move-to-folder-4-2 . "Moving mails... done (%0;d mail%1;s moved into %2;s)")
	(move-to-folder-7 . "s")
	(move-to-folder-8 . "")
	(refile-call-1 . "mail %d not found.")
	(read-contents-1 . "no mail.")
	(read-contents-2 . "no more mail.")
	(show-contents-1 . "end of folder.")
	(read-reverse-1 . "Beginning of message.")
	(next-unread-mail-1 . "No more unread mails")
	(prepare-caesar-1 . "Building caesar-translate-table...")
	(prepare-caesar-2 . "Building caesar-translate-table... done")
	(delete-bk-file-1 . "File %s does not exist.")
	(delete-bk-file-2 . "Delete file %s. Are you sure?")
	(delete-bk-file-3 . "File %s deleted.")
	(visit-folder-1 . "Visit folder") ; cmail-folders-visit-folder-directly-withou-thread, cmail-folders-visit-folder-directly
	(visit-folder-2 . "How many mails from %0;s(%1;d mails): ")
	(kill-folder-1 . "Remove folder")
	(kill-folder-2 . "Can't remove %s")
	(kill-folder-3 . "Remove %s, are you sure?")
	(kill-folder-4 . "terminated.")
	(kill-folder-5 . "Folder %s removed.")
	(copy-folder-1 . "Copy folder %s to")
	(copy-folder-2 . "folder %s is virtual.") ; used in cmail-rename-folder, too.
	(copy-folder-3 . "folder %s exists.") ; used in cmail-rename-folder, too.
	(copy-folder-4 . "folder %0;s copyed to %1;s.")
	(rename-folder-1 . "Rename folder %s to")
	(rename-folder-4 . "folder %0;s renamed to %1;s.")
	(reorder-folder-1 . "Are you sure to reorder %s?")
	(reorder-folder-2 . "Terminated.")
	(reorder-folder-3 . "Reordering %0;s...%1;d")
	(reorder-folder-4 . "Re-ordering %s... done")
	(saving-folder-1 . "Saving folder is %s")
	(saving-folder-2 . "No saving folder")
	(mark-specified-mails-1 . "Header: ")
	(mark-specified-mails-2 . "Regexp Pattern for Header %s: ")
	(mark-specified-mails-3 . "Specify header string.")
	(auto-archive-1 . "Do you want to refile %s?")
	(auto-archive-2 . "auto-refile terminated.")
	(auto-archive-3 . "Archiving...")
	(auto-archive-4 . "Archiving...%d")
	(auto-archive-5 . "Archiving... done.")
	(visit-saving-foler-1 . "Visit folder %s. Sure?")
	(scroll-up-1 . "end of message.")
	(scroll-down-1 . "beginnig of message.")
	(print-1 . "Are you ready to print this mail?")
	(print-2 . "Terminated.")
	(print-3 . "Printing...")
	(print-4 . "Printing...done.")
	(pipe-1 . "Pipe to command: ")
	(pipe-2 . "piping out message(s)...")
	(pipe-3 . "piping out message(s)... done")
	(name-and-address-1 . "get failed <get failed>")
	(name-and-address-2 . "E-mailed from... %s")
	(name-and-address-3 . "Failed.")
	(save-folder-1 . "no folder %s to save")
	(save-folder-2 . "Saving folder %s. Are you sure.?")
	(save-folder-3 . "%s is saved.")
	(save-folder-4 . "%s is not modified.")
	(save-folder-5 . "")
	(save-all-folders-1 . "folders are saved.")
	(save-all-folders-2 . "all folders are not modified.")
	(close-folder-1 . "Can't close folder %s")
	(options-load . "%0;s; option file loaded.")

	;; cmail-reply.el
	(mail2-1 . "Unsent message exists: a)bandon, r)ename or i)nclude new citation? ")
	(mail2-2 . "Unsent message exists: a)bandon or r)ename? ")
	(mail2-3 . "Previous *mail* buffer renamed to %s")
	(mail2-4 . "Merged new citation in *mail*")
	(mail2-5 . "Previous *mail* deleted")
	(mail2-6 . "Subject: ")
	(reply-1 . "%0;s's message of \"%1;s\"%2;s")
	(reply-2 . "reply for your message") ; default reply subject for empty subject
	(setup-reply-buffer-1 . "failed to get value in index.")
	(make-reply-headings-1 . "your message")
	(forward-1 . "Forward: %s")	; Subject prefix for forwarding mails
	(forward-2 . "forward")		; Default subject for forwarding mails
	(mail-this-line-1 . "Subject: ")
	(send-1 . "Are you need log ")
	(complete-address-1 . "can't find completion for \"%s\"")
	(complete-address-2 . "Making completion list...")
	(complete-address-3 . "Making completion list... done")
	(add-new-address-from-mail-1 . "Registering address: ")
	(add-new-address-from-mail-2 . "Register <%s> to .addresses?")
	(resend-bounced-mail-1 . "This does not appear to be a bounced message.")
	(resend-bounced-mail-2 . "retry of %0;s:%1;d") ; Subject?
	(mail-compose-1 . "R)eply or F)ollow ?")

	;; cmail-folders.el
	(folders-count-mails-1 . "Scannig %s...")
	(folders-count-mails-2 . "Scannig %s... done")
	(folders-load-cache-1 . "Updating folder list...")
	(folders-load-cache-2 . "Updating folder list... done")
	(after-save-all-folders-function-1 . "Saving cmail-folders cache file...") ;used in cmail-after-quit-function, too.
	(after-quit-function-2 . "Saving cmail-folders cache file... done")
	(folders-previous-unread-folder-1 . "No more unread folders") ; used in cmail-folders-next-unread-folder, too
	(folders-update-1 . "Saving folders...")
	(folders-update-2 . "Updating folder list...")
	(folders-update-3 . "Updating folder list... done")
	(folders-copy-folder-1 . "Copy folder %s to")
	(folders-copy-folder-2 . "Don't point folder.")
	(folders-rename-folder-1 . "Rename folder %s to")
	(folders-rename-folder-2 . "Don't point folder.")
	(folders-kill-dir-1 . "Remove %s, are you sure?")
	(folders-kill-folder-1 . "Don't point folder.")
	(folders-kill-folder-2 . "Can't kill a parent directory.")
	(folders-quit-internal-1 . "Are you sure you want to quit cmail?")
	(folders-close-all-folders-1 . "%s closed.")
	(folders-close-all-folders-2 . "Done.")

	;; cmail-summary.el
	(make-summary-1 . "Listing %s ...")
	(make-summary-2 . "Listing %s ... Error.")
	(make-summary-3 . "    0  \n")
	(make-summary-4 . "    0  ******** Error in listing Summary.\n")
	(make-summary-5 . "    0  ******** Possible Folder Headings data corruption.\n")
	(make-summary-6 . "    0  ******** Consider running M-x cmail-remake-folder-headings (normally M-r).\n")
	(make-summary-7 . "    0  \n")
	(make-summary-8 . "Listing %s ... Quit.")
	(make-summary-9 . "    0  \n")
	(make-summary-10 . "    0  ******** Summary Listing Interrupted.\n")
	(make-summary-11 . "    0  ******** M-x cmail-make-summary to restart.\n")
	(make-summary-12 . "    0  \n")
	(make-summary-13 . "Listing %s ...done.")
	(make-summary-line-1 . " %4s  ********  bad header format  ********\n")
	(summary-limit-1 . "can't set limit in thread-mode")
	(summary-limit-2 . "Summarize limit: ")
	(summary-limit-3 . "unset summarize limit.")
	(remake-folder-headings-1 . "Remake index, now you lose MARK data. Are you sure?")
	(remake-folder-headings-2 . "terminated.")
	(remake-folder-headings-3 . "Remake...")
	(remake-folder-headings-4 . "Remake...%d")
	(remake-folder-headings-5 . "done")
	(remake-folder-headings-6 . "Remake...done")
	(execute-index-1 . "Delete mail as index, now you lose some mails. Sure?")
	(execute-index-2 . "terminated.")
	(execute-index-3 . "Executing %s...")
	(execute-index-4 . "Executing %s... done")
	(diet-folder-1 . "Diet...")
	(diet-folder-2 . "Diet...%d")
	(diet-folder-3 . "Diet...done. %0;s contains %1;d mail%2;s.")
	(diet-folder-4 . "")
	(diet-folder-5 . "s")
	(sort-index-1 . "Sorting field:")
	(move-index-1 . "can't move index in thread-mode")
	(move-index-2 . "Moving index...")
	(move-index-3 . "no marks in this folder.")
	(move-index-4 . "Moving index...%0;d index%1;s moved.")
	(move-index-5 . "")
	(move-index-6 . "es")
	; *** cmail-goto-index (interactive "Ngoto mail:")
	(expire-mark-1 . "Expiring %s...")
	(expire-mark-2 . "Expiring %s... done")
	(catch-up-all-1 . "Do you really want to mark everything as read? ")
	(catch-up-all-2 . "Mark all unread mails as read?")
	(catch-up-all-3 . "marking...")
	(catch-up-all-4 . "marking... done")
	(mark-confirm-1 . "Type \\[delete-other-windows] to remove confirm window.")
	(mark-confirm-2 . "Type \\[switch-to-buffer] RET to remove confirm window.")
	(mark-confirm-3 . "Type \\[switch-to-buffer-other-window] RET to restore old contents of confirm window.")
	(mark-confirm-4 . "No mail marked by `%c'.")

	;; cmail-digest.el
	(burst-digest-1 . "bursting diests...")
	(burst-digest-2 . "bursting diests... done")
	(burst-internal-1 . "mail does not seem like a digest.")
	(send-digest-1 . "digest of folder %s")	;Subject:
	(send-digest-2 . "making digest...")
	(send-digest-3 . "making digest... done")

	;; cmail-misc.el
	(get-page-number-from-summary . "no mail.")
	(rebuild-index-1 . "in summary")
	(rebuild-index-2 . "Counting mails in %s...")
	(clean-virtual-folders-1 . "Mails in virtual folders may be lost. Sure?")
	(clean-virtual-folders-2 . "Terminated")
	(complete-foldername-1 . "%s(default %s): ")
	(complete-foldername-2 . "file %s is a directory.")
	(complete-filename-1 . "%s (default %s) ")
	(complete-filename-2 . "Bad match.")
	(open-folder-1 . "create new foler `%s'")
	(open-folder-2 . "folder `%s' was not created.")
	(delete-mail-1 . "Deleting this mail. Are you sure?")

	;; cmail-search.el
	(summary-search-article-forward-1 . "Search forward (regexp): ")
	(summary-search-article-forward-2 . "(default %s) ")
	(summary-search-article-forward-3 . "Search failed: %s")
	(summary-search-article-backward-1 . "Search backward (regexp): ")

	;; cmail-thread.el
	(refer-article-1 . "No references around point")
	(refer-article-mid-1 . "No parent")
	(refer-article-mid-2 . "Not found in folder %0;s - %1;s")
	(refer-article-mid-3 . "Mail %d not shown in summary")

	;; cmail-trans.el
	(m2c-1 . "Converting mbox file:")
	(m2c-2 . "Move all to folder")
	(m2c-3 . "Converting...")
	(m2c-4 . "Converting...done %0;d mbox-formed mail%1;s read")
	(m2c-5 . "")
	(m2c-6 . "s")
	(r2c-1 . "Converting RMAIL file:")
	(r2c-2 . "Move all to folder")
	(r2c-3 . "Converting...")
	(r2c-4 . "CM:File %s is not in format of RMAIL.")
	(r2c-5 . "Converting...done")
	(r2c-6 . "%0;d RMAIL-formed mail%1;s read")
	(r2c-7 . "")
	(r2c-8 . "s")
	(c2m-1 . "Convert folder")
	(c2m-2 . "%0;s %1;s in Unix mail file:")
	(c2m-3 . "Converting...")
	(c2m-4 . "Converting...done.")
	(save-mail-as-mbox-1 . "Save mail(s) in Unix mail file:")
	(save-mail-as-mbox-2 . "Done.")
	(save-mail-1 . "Save mail(s) in file:")
	(save-mail-2 . "Done.")

	;; cmail-edit.el
	(edit-1 . "Edit this message. Are you sure?")
	(edit-2 . "Terminated.")
	(edit-3 . "\\[cmail-cease-edit] to return cmail summary. \\[cmail-abort-edit] to abort.")
	(cease-edit-1 . "current folder changed while editing.")
	(cease-edit-2 . "Finish editing.")
	(abort-edit-1 . "Are you sure to abort?")
	(abort-edit-2 . "Abort editing.")
	(abort-edit-3 . "Continue editing.")
	(edit-index-1 . "Edit index of this mail. Are you sure?")
	(edit-index-2 .  "abort.")
	(edit-index-3 . "Edit index: ")
	(edit-index-4 . "abort.")
	(edit-index-5 . "done.")
))
